"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var React = require("react");
var logger_1 = require("hornet-js-logger/src/logger");
var hornet_component_1 = require("hornet-js-react-components/src/widget/component/hornet-component");
var hornet_superagent_1 = require("hornet-js-core/src/services/hornet-superagent");
var wakeup_node_1 = require("hornet-js-core/src/services/default/wakeup-node");
var classnames_1 = require("classnames");
var moment = require("moment-timezone");
var svg_sprites_1 = require("hornet-js-react-components/src/widget/icon/svg-sprites");
require("hornet-js-react-components/src/widget/notification/sass/_notification.scss");
moment.duration.fn.format = function () {
    var str = "";
    if (this.days() > 1)
        str = str + Math.floor(this.days()) + "d ";
    if (this.hours() > 1)
        str = str + Math.floor(this.hours()) + "h ";
    if (this.minutes() > 1)
        str = str + Math.floor(this.minutes()) + "m ";
    if (this.seconds() > 1)
        str = str + Math.floor(this.seconds()) + "s ";
    return str;
};
var logger = logger_1.Logger.getLogger("hornet-js-react-components.widget.notification.notification-session-footer");
var NotificationSessionFooter = /** @class */ (function (_super) {
    tslib_1.__extends(NotificationSessionFooter, _super);
    function NotificationSessionFooter(props, context) {
        var _this = _super.call(this, props, context) || this;
        /**
         * Service middleware pour prolonger la session
         */
        _this.wakeUpNodeService = new wakeup_node_1.WakeUpNode();
        /**
         * (Ré)Initialisation du timeout de masquage de la notification appelé sur lamise à jour du temps restant
         */
        _this.initAutoMaskNotificationTimeout = function () {
            if (_this.tDisplay) {
                clearTimeout(_this.tDisplay);
            }
            if (_this.formateTime() > _this.props.automaskBeforeMS) {
                _this.tDisplay = setTimeout(_this.handleToggleNotification, _this.props.displayDuration);
            }
        };
        _this.state = tslib_1.__assign(tslib_1.__assign({}, _this.state), { offset: 0 });
        return _this;
    }
    NotificationSessionFooter.prototype.componentDidMount = function () {
        window.addEventListener("scroll", this.handleScroll);
        this.listen(hornet_superagent_1.SESSION_REFRESHED_NOTIFICATION_EVENT, this.handleRefresh);
        this.listen(hornet_superagent_1.SESSION_WILL_EXPIRE_START_NOTIFICATION_EVENT, this.handleWillExpireStart);
        this.listen(hornet_superagent_1.SESSION_WILL_EXPIRE_NOTIFICATION_EVENT, this.handleWillExpire);
    };
    NotificationSessionFooter.prototype.componentWillUnmount = function () {
        window.removeEventListener("scroll", this.handleScroll);
        this.remove(hornet_superagent_1.SESSION_REFRESHED_NOTIFICATION_EVENT, this.handleRefresh);
        this.remove(hornet_superagent_1.SESSION_WILL_EXPIRE_START_NOTIFICATION_EVENT, this.handleWillExpireStart);
        this.remove(hornet_superagent_1.SESSION_WILL_EXPIRE_NOTIFICATION_EVENT, this.handleWillExpire);
    };
    NotificationSessionFooter.prototype.render = function () {
        logger.debug("NotificationSessionFooter render");
        return (this.state.isVisible ? this.renderNotification() : React.createElement("div", null));
    };
    /**
     * Méthode permettant de faire le rendu du bloc de notification
     * @returns {JSX.Element}
     */
    NotificationSessionFooter.prototype.renderNotification = function () {
        var style = {};
        /*si le footer est visible, le composant s'affichera au dessus de celui-ci*/
        if (this.state.offset < 0) {
            style = { bottom: 0 };
        }
        var divProps = {
            className: "notification-timeout flex-container",
            style: style,
            name: this.state.name,
            title: this.state.title,
            id: "notification-session"
        };
        var labelClasses = {
            "fl": true,
            "notification-session-message": true,
            "notification-expanded": !this.state.reduced,
            "notification-reduced": this.state.reduced
        };
        var btnClasses = {
            "fl": true,
            "notification-session-btn": true,
        };
        var imgSrc = React.createElement(svg_sprites_1.SvgSprites, { icon: "next", color: "#2E586E", height: "3em", width: "2em", tabIndex: -1 });
        if (this.state.reduced) {
            imgSrc = React.createElement(svg_sprites_1.SvgSprites, { icon: "previous", color: "#0579BE", height: "3em", width: "2em", tabIndex: -1 });
        }
        var tabIndex = this.state.reduced ? -1 : 0;
        return (React.createElement("div", tslib_1.__assign({}, divProps),
            React.createElement("div", { className: classnames_1.default(labelClasses) },
                React.createElement("div", null, this.formatMessage()),
                React.createElement("div", null,
                    React.createElement("a", { onClick: this.handlClickWakeUp, tabIndex: tabIndex }, this.state.expireIn <= 0 ? this.i18n(this.props.messages).reconnexion : this.i18n(this.props.messages).rafraichir))),
            React.createElement("div", { className: classnames_1.default(btnClasses) },
                React.createElement("a", { href: "", onClick: this.handleToggleNotification, tabIndex: 0, className: "notifWrap" }, imgSrc))));
    };
    /**
     * handler click pour prolonger la session
     */
    NotificationSessionFooter.prototype.handlClickWakeUp = function () {
        var _this = this;
        if (this.props.handlClickWakeUp) {
            this.props.handlClickWakeUp();
        }
        else {
            if (this.state.expireIn <= 0) {
                window.location.reload();
            }
            else {
                this.wakeUpNodeService.wakeUp().then(function () {
                    _this.handleRefresh();
                });
            }
        }
    };
    /**
     * Méthode permettant de formater le message à afficher dans le bloc de notification
     * @returns {string}
     */
    NotificationSessionFooter.prototype.formatMessage = function () {
        var message = this.i18n(this.props.messages).countDownExpiredMessage;
        var duration = this.formateTime();
        if (duration > 999) { //ms
            var momentDuration = moment.duration(duration, "milliseconds");
            var time = { minutes: momentDuration.minutes(), seconds: momentDuration.seconds() };
            time["and"] = ((time.minutes > 0 && time.seconds > 0) && "and") || undefined;
            message = this.i18n(this.i18n(this.props.messages).countDownNormalMessage, time);
        }
        return message;
    };
    /**
     * Méthode permettant de formater le state expireIn au format Date
     * @returns {number}
     */
    NotificationSessionFooter.prototype.formateTime = function () {
        return new Date(this.state.expireIn).getTime();
    };
    /**
     * Méthode permettant de réduire la notification
     */
    NotificationSessionFooter.prototype.handleToggleNotification = function () {
        this.setState({ reduced: !this.state.reduced });
    };
    /**
     * Méthode permettant de rafraichir la notification
     * @param {HornetEvent<SessionEvent>} ev
     */
    NotificationSessionFooter.prototype.handleRefresh = function (ev) {
        var elementsToUpdate = {
            isVisible: false,
            reduced: false
        };
        if (ev && ev.detail && ev.detail.value) {
            elementsToUpdate["expireIn"] = ev.detail.value;
        }
        this.setState(elementsToUpdate);
    };
    /**
     * Méthode permettant de rafraichir la notification
     * @param {HornetEvent<SessionEvent>} ev
     */
    NotificationSessionFooter.prototype.handleWillExpireStart = function (ev) {
        this.setState({ isVisible: true, expireIn: ev.detail.value }, this.initAutoMaskNotificationTimeout);
    };
    /**
     * Méthode permettant d'avertir d'une fin de session
     * @param {HornetEvent<SessionEvent>} ev
     */
    NotificationSessionFooter.prototype.handleWillExpire = function (ev) {
        this.setState({ reduced: false, expireIn: ev.detail.value }, this.initAutoMaskNotificationTimeout);
    };
    /**
     * Métohde de gestion du scroll à l'écran
     */
    NotificationSessionFooter.prototype.handleScroll = function () {
        var footer = document.getElementById(this.state.footer);
        var rect = footer.getBoundingClientRect();
        var viewHeight = Math.max(document.documentElement.clientHeight, window.innerHeight);
        //sauvegarde la taille visible du footer
        var height = -(rect.top - viewHeight);
        this.setState({ size: height });
        /*si le footer est visible, le composant s'affichera au dessus de celui-ci*/
        var visible = false;
        if (footer) {
            visible = this.checkvisible(footer);
        }
        this.setState({
            offset: height,
            visible: visible
        });
    };
    /**
     * Calcule si un élément est présent ou non a l'écran
     * @param {Element} elm - l'élément a rechercher
     * @return {boolean} true si l'élément est présent
     */
    NotificationSessionFooter.prototype.checkvisible = function (elm) {
        var rect = elm.getBoundingClientRect();
        var viewHeight = Math.max(document.documentElement.clientHeight, window.innerHeight);
        //sauvegarde la la taille visible de l'élément
        var height = -(rect.top - viewHeight) + 40;
        this.setState({ size: height });
        return !(rect.bottom < 0 || rect.top - viewHeight >= 0);
    };
    NotificationSessionFooter.defaultProps = ({
        offset: 0,
        header: "header-container",
        footer: "footer-container",
        messages: "notificationSession",
        automaskBeforeMS: 999,
        displayDuration: 8000 // 8 secondes pour eviter les collisions les repeat à 10 seondes
    });
    return NotificationSessionFooter;
}(hornet_component_1.HornetComponent));
exports.NotificationSessionFooter = NotificationSessionFooter;

//# sourceMappingURL=notification-session-footer.js.map
