"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var React = require("react");
var logger_1 = require("hornet-js-logger/src/logger");
var hornet_js_utils_1 = require("hornet-js-utils");
var hornet_component_1 = require("hornet-js-react-components/src/widget/component/hornet-component");
var classnames_1 = require("classnames");
var svg_sprites_1 = require("../icon/svg-sprites");
require("hornet-js-react-components/src/widget/notification/sass/_notification.scss");
var logger = logger_1.Logger.getLogger("hornet-js-react-components.widget.notification.notification-message-item");
var SessionIdpExpireNotification = /** @class */ (function (_super) {
    tslib_1.__extends(SessionIdpExpireNotification, _super);
    function SessionIdpExpireNotification(props, context) {
        return _super.call(this, props, context) || this;
    }
    SessionIdpExpireNotification.prototype.componentDidMount = function () {
        var _this = this;
        if (!hornet_js_utils_1.Utils.isServer) {
            this.timeoutHandler = setTimeout(function () {
                _this.setState({ isVisible: true });
            }, this.props.expireInDate - (this.props.expireIn));
        }
    };
    SessionIdpExpireNotification.prototype.render = function () {
        return (React.createElement("div", null, this.state.isVisible ? this.renderNotification() : null));
    };
    SessionIdpExpireNotification.prototype.componentWillUnmount = function () {
        clearTimeout(this.timeoutHandler);
    };
    SessionIdpExpireNotification.prototype.componentDidUpdate = function () {
        if (this.state.isVisible === false && this.activeElement && this.activeElement.focus) {
            this.activeElement.focus();
        }
    };
    /**
     * Méthode permettant de faire le rendu du bloc de notification
     * @returns {JSX.Element}
     */
    SessionIdpExpireNotification.prototype.renderNotification = function () {
        logger.debug("SessionIdpExpireNotification renderNotification");
        this.activeElement = undefined;
        if (window && window.document && window.document.activeElement) {
            this.activeElement = document.activeElement;
        }
        var style = {};
        /*si le footer est visible, le composant s'affichera au dessus de celui-ci*/
        if (this.state.offset < 0) {
            style = { bottom: 0 };
        }
        var divProps = {
            className: "notification-idp-timeout flex-container",
            style: style,
            name: this.state.name,
            title: this.state.title,
            id: "notification-idp-session"
        };
        var labelClasses = {
            "fl": true,
            "notification-session-idp-message": true,
            "notification-idp-expanded": !this.state.reduced,
            "notification-idp-reduced": this.state.reduced
        };
        return (React.createElement("div", tslib_1.__assign({}, divProps),
            React.createElement("div", { className: "fl notification-session-idp-button", onClick: this.handleToggleNotification },
                React.createElement("a", { href: "", onClick: this.handleToggleNotification, tabIndex: 0 },
                    React.createElement(svg_sprites_1.SvgSprites, { icon: "close", color: "#2E586E", tabIndex: -1 }))),
            React.createElement("div", { className: classnames_1.default(labelClasses) },
                React.createElement("div", { className: "notification-idp-message", role: "log" }, this.i18n(this.props.notificationMessage, { expireIn: this.props.expireIn / 1000 })),
                this.props.children ? React.createElement("div", { className: "notification-idp-children" }, this.props.children) : null)));
    };
    /**
     * Méthode permettant de réduire la notification
     */
    SessionIdpExpireNotification.prototype.handleToggleNotification = function () {
        this.setState({ isVisible: !this.state.isVisible });
    };
    /**
     * Calcule si un élément est présent ou non a l'écran
     * @param {Element} elm - l'élément a rechercher
     * @return {boolean} true si l'élément est présent
     */
    SessionIdpExpireNotification.prototype.checkvisible = function (elm) {
        var rect = elm.getBoundingClientRect();
        var viewHeight = Math.max(document.documentElement.clientHeight, window.innerHeight);
        // sauvegarde la la taille visible de l'élément
        var height = -(rect.top - viewHeight) + 40;
        this.setState({ size: height });
        return !(rect.bottom < 0 || rect.top - viewHeight >= 0);
    };
    SessionIdpExpireNotification.defaultProps = {
        notificationMessage: "notificationIdp.expireMessage",
        expireIn: 60000,
        expireInDate: 60000,
        reduced: false
    };
    return SessionIdpExpireNotification;
}(hornet_component_1.HornetComponent));
exports.SessionIdpExpireNotification = SessionIdpExpireNotification;

//# sourceMappingURL=notification-session-idp.js.map
